@@ -76,7 +76,7 @@ class BasePublisher(object):
         '''View dispatcher called by Django'''
         self.action = action
         method = request.method.lower()
-        prefix = 'object' if object_id else 'list'
+        self.mode = prefix = 'object' if object_id else 'list'
         handler = getattr(self, '%s_%s_%s' % (prefix, method, action), None)
         if handler is None:
             # See if there's a method agnostic handler
@@ -103,13 +103,13 @@ class BasePublisher(object):
 
             if parts[0] == 'list':
                 if len(parts) == 2:
-                    list_handlers[parts[1]].append(getattr(fnc, '_accepts', 'ALL'))
+                    list_handlers[parts[1]].extend(getattr(fnc, '_accepts', ['ALL']))
                 else:
                     list_handlers[parts[2]].append(parts[1])
 
             elif parts[0] == 'object':
                 if len(parts) == 2:
-                    object_handlers[parts[1]].append(getattr(fnc, '_accepts', 'ALL'))
+                    object_handlers[parts[1]].extend(getattr(fnc, '_accepts', ['ALL']))
                 else:
                     object_handlers[parts[2]].append(parts[1])
 
@@ -126,6 +126,12 @@ class Publisher(engine.JsonEngine, BasePublisher):
         '''Return the serialiser instance to use for this request'''
         return self.serialiser
 
+    def get_serialiser_kwargs(self):
+        '''Allow passing of extra kwargs to serialiser calls'''
+        return {
+            'publisher': self,
+        }
+
     def get_object_list(self): # pragma: no cover
         '''Return the object list appropriate for this request'''
         raise NotImplementedError
@@ -157,7 +163,7 @@ class Publisher(engine.JsonEngine, BasePublisher):
             'objects': page.object_list,
         }
 
-    def get_data(self):
+    def get_request_data(self):
         '''Retrieve data from request'''
         if self.request.META.get('CONTENT_TYPE', '') in self.CONTENT_TYPES:
             if not self.request.body:
@@ -171,7 +177,10 @@ class Publisher(engine.JsonEngine, BasePublisher):
         '''Helper to return a single object instance serialised.'''
         if serialiser is None:
             serialiser = self.get_serialiser()
-        data = serialiser.deflate_object(obj, publisher=self)
+        serialiser_kwargs = response_kwargs.pop('serialiser_kwargs', None)
+        if serialiser_kwargs is None:
+            serialiser_kwargs = self.get_serialiser_kwargs()
+        data = serialiser.deflate_object(obj, **serialiser_kwargs)
         return self.create_response(data, **response_kwargs)
 
     def create_response(self, content, **response_kwargs):
@@ -185,7 +194,8 @@ class Publisher(engine.JsonEngine, BasePublisher):
         data = self.get_page(object_list)
 
         serialiser = self.get_serialiser()
-        data['objects'] = serialiser.deflate_list(data['objects'], publisher=self)
+        serialiser_kwargs = self.get_serialiser_kwargs()
+        data['objects'] = serialiser.deflate_list(data['objects'], **serialiser_kwargs)
         return self.create_response(data)
 
     def object_get_default(self, request, object_id, **kwargs):
